@@ -13,6 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import json
+import logging
 import os
 import shutil
 import six
@@ -28,6 +29,8 @@ from oslo_concurrency import processutils
 from tripleo_common.actions import base
 from tripleo_common.inventory import TripleoInventory
 
+LOG = logging.getLogger(__name__)
+
 
 def write_default_ansible_cfg(work_dir,
                               base_ansible_cfg='/etc/ansible/ansible.cfg'):
@@ -40,22 +43,10 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'retry_files_enabled', 'False')
     config.set('defaults', 'log_path',
                os.path.join(work_dir, 'ansible.log'))
-    config.set('defaults', 'forks', '25')
-    config.set('defaults', 'timeout', '30')
-    config.set('defaults', 'gather_timeout', '30')
 
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
-               '-o UserKnownHostsFile=/dev/null '
-               '-o StrictHostKeyChecking=no '
-               '-o ControlMaster=auto '
-               '-o ControlPersist=30m '
-               '-o ServerAliveInterval=5 '
-               '-o ServerAliveCountMax=5')
-    config.set('ssh_connection', 'control_path_dir',
-               os.path.join(work_dir, 'ansible-ssh'))
-    config.set('ssh_connection', 'retries', '8')
-    config.set('ssh_connection', 'pipelining', 'True')
+               '-o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no')
 
     with open(ansible_config_path, 'w') as configfile:
         config.write(configfile)
@@ -71,7 +62,7 @@ class AnsibleAction(actions.Action):
         self.hosts = self._kwargs_for_run.pop('hosts', None)
         self.module = self._kwargs_for_run.pop('module', None)
         self.module_args = self._kwargs_for_run.pop('module_args', None)
-        if self.module_args and isinstance(self.module_args, dict):
+        if self.module_args:
             self.module_args = json.dumps(self.module_args)
         self.limit_hosts = self._kwargs_for_run.pop('limit_hosts', None)
         self.remote_user = self._kwargs_for_run.pop('remote_user', None)
@@ -97,6 +88,7 @@ class AnsibleAction(actions.Action):
             'use_openstack_credentials', False)
         self.extra_env_variables = self._kwargs_for_run.pop(
             'extra_env_variables', None)
+        self.gather_facts = self._kwargs_for_run.pop('gather_facts', False)
 
         self._work_dir = None
 
@@ -208,11 +200,13 @@ class AnsibleAction(actions.Action):
                 msg = "extra_env_variables must be a dict"
                 return actions.Result(error=msg)
 
+        if self.gather_facts:
+            command.extend(['--gather-facts', self.gather_facts])
+
         try:
             ansible_config_path = write_default_ansible_cfg(self.work_dir)
             env_variables = {
                 'HOME': self.work_dir,
-                'ANSIBLE_LOCAL_TEMP': self.work_dir,
                 'ANSIBLE_CONFIG': ansible_config_path
             }
 
@@ -226,6 +220,8 @@ class AnsibleAction(actions.Action):
                     'OS_AUTH_TOKEN': context.security.auth_token,
                     'OS_PROJECT_NAME': context.security.project_name})
 
+            LOG.info('Running ansible command: %s', command)
+
             stderr, stdout = processutils.execute(
                 *command, cwd=self.work_dir,
                 env_variables=env_variables,
@@ -280,12 +276,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
             'work_dir', None)
         self.max_message_size = self._kwargs_for_run.pop(
             'max_message_size', 1048576)
-        self.trash_output = self._kwargs_for_run.pop('trash_output', False)
-        self.profile_tasks = self._kwargs_for_run.pop('profile_tasks', True)
-        self.profile_tasks_limit = self._kwargs_for_run.pop(
-            'profile_tasks_limit', 0)
-        self.blacklisted_hostnames = self._kwargs_for_run.pop(
-            'blacklisted_hostnames', [])
+        self.gather_facts = self._kwargs_for_run.pop('gather_facts', False)
 
     @property
     def work_dir(self):
@@ -442,11 +433,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if self.ssh_private_key:
             command.extend(['--private-key', self.ssh_private_key])
 
-        if self.blacklisted_hostnames:
-            host_pattern = ':'.join(
-                ['!%s' % h for h in self.blacklisted_hostnames])
-            command.extend(['--limit', host_pattern])
-
         if self.tags:
             command.extend(['--tags', self.tags])
 
@@ -461,23 +447,16 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 for key, value in self.extra_env_variables.items():
                     self.extra_env_variables[key] = six.text_type(value)
 
+        if self.gather_facts:
+            command.extend(['--gather-facts', self.gather_facts])
+
         try:
             ansible_config_path = write_default_ansible_cfg(self.work_dir)
             env_variables = {
                 'HOME': self.work_dir,
-                'ANSIBLE_LOCAL_TEMP': self.work_dir,
-                'ANSIBLE_CONFIG': ansible_config_path,
+                'ANSIBLE_CONFIG': ansible_config_path
             }
 
-            if self.profile_tasks:
-                env_variables.update({
-                    # the whitelist could be collected from multiple
-                    # arguments if we find a use case for it
-                    'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
-                    'PROFILE_TASKS_TASK_OUTPUT_LIMIT':
-                        six.text_type(self.profile_tasks_limit),
-                })
-
             if self.extra_env_variables:
                 env_variables.update(self.extra_env_variables)
 
@@ -520,8 +499,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 lines = []
                 for line in iter(process.stdout.readline, b''):
                     lines.append(line)
-                    if not self.trash_output:
-                        stdout.append(line)
+                    stdout.append(line)
                     if time.time() - start > 30:
                         self.post_message(queue, ''.join(lines))
                         lines = []
@@ -536,13 +514,12 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 return {"stdout": "".join(stdout), "returncode": returncode,
                         "stderr": ""}
 
+            LOG.info('Running ansible-playbook command: %s', command)
+
             stderr, stdout = processutils.execute(
                 *command, cwd=self.work_dir,
                 env_variables=env_variables,
                 log_errors=processutils.LogErrors.ALL)
-            if self.trash_output:
-                stdout = ""
-                stderr = ""
             return {"stderr": stderr, "stdout": stdout,
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
