@@ -137,6 +137,8 @@ class DeletePlanAction(base.TripleOAction):
 class ListRolesAction(base.TripleOAction):
     """Returns a deployment plan's roles
 
+    DEPRECATED, please use tripleo.plan_management.v1.list_roles workflow
+
     Parses roles_data.yaml and returns the names of all available roles.
 
     :param container: name of the Swift container / plan name
@@ -186,15 +188,13 @@ class ExportPlanAction(base.TripleOAction):
 
     def run(self, context):
         swift = self.get_object_client(context)
-        swift_service = self.get_object_service(context)
-
         tmp_dir = tempfile.mkdtemp()
         tarball_name = '%s.tar.gz' % self.plan
 
         try:
             swiftutils.download_container(swift, self.plan, tmp_dir)
             swiftutils.create_and_upload_tarball(
-                swift_service, tmp_dir, self.exports_container, tarball_name,
+                swift, tmp_dir, self.exports_container, tarball_name,
                 delete_after=self.delete_after)
         except swiftexceptions.ClientException as err:
             msg = "Error attempting an operation on container: %s" % err
