@@ -94,6 +94,21 @@ class UploadTemplatesAction(base.TripleOAction):
                 self.container)
 
 
+class UploadPlanEnvironmentAction(base.TripleOAction):
+    """Upload the plan environment into swift"""
+    def __init__(self, plan_environment,
+                 container=constants.DEFAULT_CONTAINER_NAME):
+        super(UploadPlanEnvironmentAction, self).__init__()
+        self.container = container
+        self.plan_environment = plan_environment
+
+    def run(self, context):
+        # Get object client
+        swift = self.get_object_client(context)
+        # Push plan environment to the swift container
+        plan_utils.put_env(swift, self.plan_environment)
+
+
 class ProcessTemplatesAction(base.TripleOAction):
     """Process Templates and Environments
 
@@ -265,6 +280,13 @@ class ProcessTemplatesAction(base.TripleOAction):
                          os.path.basename(f).replace('.role.j2.yaml',
                                                      '.yaml')])
                     out_f_path = os.path.join(os.path.dirname(f), out_f)
+                    if ('network/config' in os.path.dirname(f) and
+                            r_map[role].get('deprecated_nic_config_name')):
+                        d_name = r_map[role].get('deprecated_nic_config_name')
+                        out_f_path = os.path.join(os.path.dirname(f), d_name)
+                    elif ('network/config' in os.path.dirname(f)):
+                        d_name = "%s.yaml" % role.lower()
+                        out_f_path = os.path.join(os.path.dirname(f), d_name)
                     if not (out_f_path in excl_templates):
                         if '{{role.name}}' in j2_template:
                             j2_data = {'role': r_map[role],
