@@ -54,6 +54,9 @@ DEFAULT_TEMPLATES_PATH = '/usr/share/openstack-tripleo-heat-templates/'
 DEFAULT_VALIDATIONS_PATH = \
     '/usr/share/openstack-tripleo-validations/validations/'
 
+# The path to the local CA certificate installed on the undercloud
+LOCAL_CACERT_PATH = '/etc/pki/ca-trust/source/anchors/cm-local-ca.pem'
+
 # TRIPLEO_META_USAGE_KEY is inserted into metadata for containers created in
 # Swift via SwiftPlanStorageBackend to identify them from other containers
 TRIPLEO_META_USAGE_KEY = 'x-container-meta-usage-tripleo'
@@ -102,14 +105,14 @@ PASSWORD_PARAMETER_NAMES = (
     'NovaPassword',
     'NovajoinPassword',
     'MigrationSshKey',
-    'OctaviaServerCertsKeyPassphrase',
     'OctaviaCaKeyPassphrase',
     'OctaviaHeartbeatKey',
     'OctaviaPassword',
-    'OpenDaylightPassword',
     'PacemakerRemoteAuthkey',
     'PankoPassword',
     'PcsdPassword',
+    'RpcPassword',
+    'NotifyPassword',
     'RabbitCookie',
     'RabbitPassword',
     'RedisPassword',
@@ -168,9 +171,3 @@ TRIPLEO_DEPLOYMENT_RESOURCE = 'TripleODeployment'
 HOST_NETWORK = 'ctlplane'
 
 EXTERNAL_TASKS = ['external_deploy_tasks']
-
-ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
-
-DEPLOYMENT_STATUS_FILE = 'deployment_status.yaml'
-
-MISTRAL_WORK_DIR = '/var/lib/mistral'
