@@ -20,30 +20,128 @@ import os
 import re
 import subprocess
 import sys
+import tempfile
 import yaml
 
 from tripleo_common.image import base
 from tripleo_common.image import image_uploader
 
+CONTAINER_IMAGE_PREPARE_PARAM = [{
+    'tag_from_label': 'rdo_version',
+    'set': {
+        'namespace': 'docker.io/tripleomaster',
+        'ceph_namespace': 'docker.io/ceph',
+        'ceph_image': 'daemon',
+        'ceph_tag': 'v3.0.1-stable-3.0-luminous-centos-7-x86_64',
+        'name_prefix': 'centos-binary-',
+        'name_suffix': '',
+        'tag': 'current-tripleo',
+        'neutron_driver': None,
+    }
+}]
 
-CONTAINER_IMAGES_DEFAULTS = {
-    'namespace': 'docker.io/tripleoqueens',
-    'ceph_namespace': 'docker.io/ceph',
-    'ceph_image': 'daemon',
-    'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
-    'name_prefix': 'centos-binary-',
-    'name_suffix': '',
-    'tag': 'current-tripleo',
-    'neutron_driver': None,
-    'logging': 'files'
-}
+CONTAINER_IMAGES_DEFAULTS = CONTAINER_IMAGE_PREPARE_PARAM[0]['set']
 
 DEFAULT_TEMPLATE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                      'container-images',
                                      'overcloud_containers.yaml.j2')
 
 
+def get_enabled_services(environment, roles_data):
+    """Build list of enabled services
+
+    :param environment: Heat environment for deployment
+    :param roles_data: Roles file data used to filter services
+    :returns: set of resource types representing enabled services
+    """
+    enabled_services = set()
+    parameter_defaults = environment.get('parameter_defaults', {})
+    for role in roles_data:
+        count = parameter_defaults.get('%sCount' % role['name'],
+                                       role.get('CountDefault', 0))
+        if count > 0:
+            enabled_services.update(
+                parameter_defaults.get('%sServices' % role['name'],
+                                       role.get('ServicesDefault', [])))
+    return enabled_services
+
+
+def build_service_filter(environment, roles_data):
+    """Build list of containerized services
+
+    :param environment: Heat environment for deployment
+    :param roles_data: Roles file data used to filter services
+    :returns: set of resource types representing containerized services
+    """
+    enabled_services = get_enabled_services(environment, roles_data)
+    containerized_services = set()
+    for service, env_path in environment.get('resource_registry', {}).items():
+        # Use the template path to determine if it represents a
+        # containerized service
+        if '/docker/services/' in env_path:
+            containerized_services.add(service)
+
+    return containerized_services.intersection(enabled_services)
+
+
+def container_images_prepare_multi(environment, roles_data):
+    """Perform multiple container image prepares and merge result
+
+    Given the full heat environment and roles data, perform multiple image
+    prepare operations. The data to drive the multiple prepares is taken from
+    the ContainerImagePrepare parameter in the provided environment. If
+    push_destination is specified, uploads will be performed during the
+    preparation.
+
+    :param environment: Heat environment for deployment
+    :param roles_data: Roles file data used to filter services
+    :returns: dict containing merged container image parameters from all
+              prepare operations
+    """
+
+    pd = environment.get('parameter_defaults', {})
+    cip = pd.get('ContainerImagePrepare')
+    if not cip:
+        return
+
+    env_params = {}
+    service_filter = build_service_filter(environment, roles_data)
+
+    for cip_entry in cip:
+        mapping_args = cip_entry.get('set')
+        push_destination = cip_entry.get('push_destination')
+        pull_source = cip_entry.get('pull_source')
+
+        prepare_data = container_images_prepare(
+            excludes=cip_entry.get('excludes'),
+            service_filter=service_filter,
+            pull_source=pull_source,
+            push_destination=push_destination,
+            mapping_args=mapping_args,
+            output_env_file='image_params',
+            output_images_file='upload_data',
+            tag_from_label=cip_entry.get('tag_from_label'),
+        )
+        env_params.update(prepare_data['image_params'])
+
+        if push_destination or pull_source:
+            with tempfile.NamedTemporaryFile(mode='w') as f:
+                yaml.safe_dump({
+                    'container_images': prepare_data['upload_data']
+                }, f)
+                uploader = image_uploader.ImageUploadManager(
+                    [f.name], verbose=True)
+                uploader.upload()
+    return env_params
+
+
 def container_images_prepare_defaults():
+    """Return default dict for prepare substitutions
+
+    This can be used as the mapping_args argument to the
+    container_images_prepare function to get the same result as not specifying
+    any mapping_args.
+    """
     return KollaImageBuilder.container_images_template_inputs()
 
 
@@ -52,10 +150,35 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                              pull_source=None, push_destination=None,
                              mapping_args=None, output_env_file=None,
                              output_images_file=None, tag_from_label=None):
+    """Perform container image preparation
+
+    :param template_file: path to Jinja2 file containing all image entries
+    :param excludes: list of image name substrings to use for exclude filter
+    :param service_filter: set of heat resource types for containerized
+                           services to filter by. Disable by passing None.
+    :param pull_source: DEPRECATED namespace for pulling during image uploads
+    :param push_destination: namespace for pushing during image uploads. When
+                             specified the image parameters will use this
+                             namespace too.
+    :param mapping_args: dict containing substitutions for template file. See
+                         CONTAINER_IMAGES_DEFAULTS for expected keys.
+    :param output_env_file: key to use for heat environment parameter data
+    :param output_images_file: key to use for image upload data
+    :param tag_from_label: string when set will trigger tag discovery on every
+                           image
+    :returns: dict with entries for the supplied output_env_file or
+              output_images_file
+    """
 
     if mapping_args is None:
         mapping_args = {}
 
+    if service_filter:
+        if 'OS::TripleO::Services::OpenDaylightApi' in service_filter:
+            mapping_args['neutron_driver'] = 'odl'
+        elif 'OS::TripleO::Services::OVNController' in service_filter:
+            mapping_args['neutron_driver'] = 'ovn'
+
     def ffunc(entry):
         imagename = entry.get('imagename', '')
         if excludes:
@@ -114,6 +237,12 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
 
 
 def detect_insecure_registries(params):
+    """Detect insecure registries in image parameters
+
+    :param params: dict of container image parameters
+    :returns: dict containing DockerInsecureRegistryAddress parameter to be
+              merged into other parameters
+    """
     insecure = set()
     uploader = image_uploader.ImageUploadManager().uploader('docker')
     for image in params.values():
