@@ -85,12 +85,10 @@ class StackOutputs(object):
 class TripleoInventory(object):
     def __init__(self, configs=None, session=None, hclient=None,
                  plan_name=None, auth_url=None, project_name=None,
-                 cacert=None, username=None, ansible_ssh_user=None,
-                 host_network=None):
+                 cacert=None, username=None, ansible_ssh_user=None):
         self.session = session
         self.hclient = hclient
         self.hosts_format_dict = False
-        self.host_network = host_network or HOST_NETWORK
         if configs is not None:
             # FIXME(shardy) backwards compatibility until we switch
             # tripleo-validations to pass the individual values
@@ -108,7 +106,6 @@ class TripleoInventory(object):
             self.ansible_ssh_user = ansible_ssh_user
             self.plan_name = plan_name
         self.stack_outputs = StackOutputs(self.plan_name, self.hclient)
-        self.hostvars = {}
 
     @staticmethod
     def get_roles_by_service(enabled_services):
@@ -155,12 +152,11 @@ class TripleoInventory(object):
     def list(self):
         ret = OrderedDict({
             'Undercloud': {
-                'hosts': self._hosts(['undercloud']),
+                'hosts': {
+                    'undercloud': {
+                        'ansible_host': 'localhost'}},
                 'vars': {
-                    'ansible_host': 'localhost',
                     'ansible_connection': 'local',
-                    # see https://github.com/ansible/ansible/issues/41808
-                    'ansible_remote_tmp': '/tmp/ansible-${USER}',
                     'auth_url': self.auth_url,
                     'cacert': self.cacert,
                     'os_auth_token':
@@ -205,11 +201,9 @@ class TripleoInventory(object):
         children = []
         for role, hostnames in role_net_hostname_map.items():
             if hostnames:
-                names = hostnames.get(self.host_network) or []
-                shortnames = [n.split(".%s." % self.host_network)[0].lower()
-                              for n in names]
-                # Create a group per hostname to map hostname to IP
-                ips = role_net_ip_map[role][self.host_network]
+                names = hostnames.get(HOST_NETWORK) or []
+                shortnames = [n.split(".%s." % HOST_NETWORK)[0] for n in names]
+                ips = role_net_ip_map[role][HOST_NETWORK]
                 hosts = {}
                 for idx, name in enumerate(shortnames):
                     hosts[name] = {}
@@ -231,29 +225,16 @@ class TripleoInventory(object):
                     networks.update(hosts[name]['enabled_networks'])
 
                 children.append(role)
-
-                if self.hosts_format_dict:
-                    hosts_format = hosts
-                else:
-                    hosts_format = [h for h in hosts.keys()]
-                    hosts_format.sort()
-
                 ret[role] = {
-                    'hosts': hosts_format,
+                    'hosts': hosts,
                     'vars': {
                         'ansible_ssh_user': self.ansible_ssh_user,
                         'bootstrap_server_id': role_node_id_map.get(
                             'bootstrap_server_id'),
-                        # Keep "role_name" until we get rid of it
-                        # https://bugs.launchpad.net/tripleo/+bug/1771171
                         'role_name': role,
-                        'tripleo_role_name': role,
                     }
-
                 }
 
-                self.hostvars.update(hosts)
-
         if children:
             vip_map = self.stack_outputs.get('VipMap', {})
             vips = {(vip_name + "_vip"): vip
@@ -278,10 +259,8 @@ class TripleoInventory(object):
                     }
                 }
 
-        if not self.hosts_format_dict:
-            # Prevent Ansible from repeatedly calling us to get empty host
-            # details
-            ret['_meta'] = {'hostvars': self.hostvars}
+        # Prevent Ansible from repeatedly calling us to get empty host details
+        ret['_meta'] = {'hostvars': {}}
 
         return ret
 
