@@ -45,6 +45,8 @@ _EXISTING_PASSWORDS = {
     'CongressPassword': 'DwcKvMqXMuNYYFU4zTCuG4234',
     'GlancePassword': 'VqJYNEdKKsGZtgnHct77XBtrV',
     'RabbitPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
+    'RpcPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
+    'NotifyPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'CephAdminKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'HAProxyStatsPassword': 'P8tbdK6n4YUkTaUyy8XgEVTe6',
     'TackerPassword': 'DwcKvMqXMuNYYFU4zTCuG4234',
@@ -57,7 +59,6 @@ _EXISTING_PASSWORDS = {
     'PankoPassword': 'cVZXehsSc2KdmFFMKDudxTLKn',
     'OctaviaHeartbeatKey': 'oct-heartbeat-key',
     'OctaviaPassword': 'NMl7j3nKk1VVwMxUZC8Cgw==',
-    'OctaviaServerCertsKeyPassphrase': 'aW5zZWN1cmUta2V5LWRvLW5vdC11c2U=',
     'OctaviaCaKeyPassphrase': 'SLj4c3uCk4DDxPwQOG1Heb==',
     'ManilaPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'NeutronMetadataProxySharedSecret': 'Q2YgUCwmBkYdqsdhhCF4hbghu',
@@ -150,7 +151,6 @@ _EXISTING_PASSWORDS = {
         'public_key': 'public_key'
         },
     'LibvirtTLSPassword': 'xCdt9yeamKz8Fb6EGba9u82XU',
-    'OpenDaylightPassword': 'abc487gfh017rmviuq75jdiw7',
 }
 
 
@@ -874,10 +874,6 @@ class GenerateFencingParametersActionTestCase(base.TestCase):
             "11:22:33:44:55:66": {
                 "compute_name": "compute_name_1",
                 "baremetal_name": "baremetal_name_1"
-                },
-            "bb:cc:dd:ee:ff:gg": {
-                "compute_name": "compute_name_5",
-                "baremetal_name": "baremetal_name_5"
                 }
             }
         mock_generate_hostmap.return_value = test_hostmap
@@ -901,17 +897,6 @@ class GenerateFencingParametersActionTestCase(base.TestCase):
             "mac": [
                 "11:22:33:44:55:66"
             ]
-        }, {
-            # This is an extra node on oVirt/RHV
-            "name": "control-3",
-            "pm_password": "ovirt-password",
-            "pm_type": "staging-ovirt",
-            "pm_user": "admin@internal",
-            "pm_addr": "3.4.5.6",
-            "pm_vm_name": "control-3",
-            "mac": [
-                "bb:cc:dd:ee:ff:gg"
-            ]
         }, {
             # This is an extra node that is not in the hostmap, to ensure we
             # cope with unprovisioned nodes
@@ -941,7 +926,7 @@ class GenerateFencingParametersActionTestCase(base.TestCase):
         result = action.run(mock_ctx)["parameter_defaults"]
 
         self.assertTrue(result["EnableFencing"])
-        self.assertEqual(len(result["FencingConfig"]["devices"]), 3)
+        self.assertEqual(len(result["FencingConfig"]["devices"]), 2)
         self.assertEqual(result["FencingConfig"]["devices"][0], {
                          "agent": "fence_ipmilan",
                          "host_mac": "00:11:22:33:44:55",
@@ -968,20 +953,6 @@ class GenerateFencingParametersActionTestCase(base.TestCase):
                              "pcmk_host_map": "compute_name_1:baremetal_name_1"
                              }
                          })
-        self.assertEqual(result["FencingConfig"]["devices"][2], {
-                         "agent": "fence_rhevm",
-                         "host_mac": "bb:cc:dd:ee:ff:gg",
-                         "params": {
-                             "delay": 28,
-                             "ipaddr": "3.4.5.6",
-                             "login": "admin@internal",
-                             "passwd": "ovirt-password",
-                             "port": "control-3",
-                             "ssl": 1,
-                             "ssl_insecure": 1,
-                             "pcmk_host_list": "compute_name_5"
-                             }
-                         })
 
 
 class GetFlattenedParametersActionTest(base.TestCase):
