@@ -28,12 +28,12 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: docker.io/tripleoqueens/heat-docker-agents-centos:latest
+    - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
       push_destination: localhost:8787
-    - imagename: docker.io/tripleoqueens/centos-binary-nova-compute:liberty
+    - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
       push_destination: localhost:8787
-    - imagename: docker.io/tripleoqueens/centos-binary-nova-libvirt:liberty
-    - imagename: docker.io/tripleoqueens/image-with-missing-tag
+    - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
+    - imagename: docker.io/tripleomaster/image-with-missing-tag
       push_destination: localhost:8787
 """)
 
@@ -56,8 +56,11 @@ class TestImageUploadManager(base.TestCase):
     @mock.patch('os.path.isfile', return_value=True)
     @mock.patch('fcntl.ioctl', side_effect=Exception)
     @mock.patch('tripleo_common.image.image_uploader.Client')
-    def test_file_parsing(self, mockdocker, mockioctl, mockpath,
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'get_undercloud_registry', return_value='192.0.2.0:8787')
+    def test_file_parsing(self, mock_gur, mockdocker, mockioctl, mockpath,
                           mock_images_match, mock_is_insecure):
+
         manager = image_uploader.ImageUploadManager(self.filelist, debug=True)
         parsed_data = manager.upload()
         mockpath(self.filelist[0])
@@ -71,25 +74,43 @@ class TestImageUploadManager(base.TestCase):
 
         dockerc = mockdocker.return_value
         dockerc.remove_image.assert_has_calls([
-            mock.call('docker.io/tripleoqueens'
-                      '/centos-binary-nova-compute:liberty'),
-            mock.call('docker.io/tripleoqueens'
+            mock.call('192.0.2.0:8787/tripleomaster'
                       '/centos-binary-nova-libvirt:liberty'),
-            mock.call('docker.io/tripleoqueens'
+            mock.call('docker.io/tripleomaster'
+                      '/centos-binary-nova-compute:liberty'),
+            mock.call('docker.io/tripleomaster'
+                      '/centos-binary-nova-libvirt:liberty'),
+            mock.call('docker.io/tripleomaster'
                       '/heat-docker-agents-centos:latest'),
-            mock.call('docker.io/tripleoqueens'
+            mock.call('docker.io/tripleomaster'
                       '/image-with-missing-tag:latest'),
 
-            mock.call('localhost:8787/tripleoqueens'
+            mock.call('localhost:8787/tripleomaster'
                       '/centos-binary-nova-compute:liberty'),
-            mock.call('localhost:8787/tripleoqueens'
-                      '/centos-binary-nova-libvirt:liberty'),
-            mock.call('localhost:8787/tripleoqueens'
+            mock.call('localhost:8787/tripleomaster'
                       '/heat-docker-agents-centos:latest'),
-            mock.call('localhost:8787/tripleoqueens/'
+            mock.call('localhost:8787/tripleomaster/'
                       'image-with-missing-tag:latest'),
         ])
 
+    @mock.patch('netifaces.ifaddresses')
+    @mock.patch('netifaces.interfaces')
+    def test_get_undercloud_registry(self, mock_interfaces, mock_addresses):
+        mock_interfaces.return_value = ['lo', 'eth0']
+        self.assertEqual(
+            'localhost:8787',
+            image_uploader.get_undercloud_registry()
+        )
+
+        mock_interfaces.return_value = ['lo', 'eth0', 'br-ctlplane']
+        mock_addresses.return_value = {
+            2: [{'addr': '192.0.2.0'}]
+        }
+        self.assertEqual(
+            '192.0.2.0:8787',
+            image_uploader.get_undercloud_registry()
+        )
+
 
 class TestImageUploader(base.TestCase):
 
@@ -375,7 +396,7 @@ class TestDockerImageUploader(base.TestCase):
             ('docker.io/t/foo', 'rdo_version', sr)
         )
 
-    @mock.patch('multiprocessing.Pool')
+    @mock.patch('concurrent.futures.ThreadPoolExecutor')
     def test_discover_image_tags(self, mock_pool):
         mock_pool.return_value.map.return_value = (
             ('docker.io/t/foo', 'a'),
