@@ -34,14 +34,14 @@ TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
 
 
 filedata = six.u("""container_images:
-- imagename: docker.io/tripleoqueens/heat-docker-agents-centos:latest
+- imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
   push_destination: localhost:8787
-- imagename: docker.io/tripleoqueens/centos-binary-nova-compute:liberty
+- imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
   uploader: docker
   push_destination: localhost:8787
-- imagename: docker.io/tripleoqueens/centos-binary-nova-libvirt:liberty
+- imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
   uploader: docker
-- imagename: docker.io/tripleoqueens/image-with-missing-tag
+- imagename: docker.io/tripleomaster/image-with-missing-tag
   push_destination: localhost:8787
 """)
 
@@ -164,11 +164,10 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': 'docker.io/tripleoqueens',
+                'namespace': 'docker.io/tripleomaster',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
-                'logging': 'files',
+                'ceph_tag': 'v3.0.1-stable-3.0-luminous-centos-7-x86_64',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
@@ -179,18 +178,17 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': '192.0.2.0:5000/tripleoqueens',
+                'namespace': '192.0.2.0:5000/tripleomaster',
                 'ceph_namespace': 'docker.io/cephh',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
-                'logging': 'stdout',
                 'name_prefix': 'prefix-',
                 'name_suffix': '-suffix',
                 'tag': 'master',
                 'neutron_driver': 'ovn'
             },
             builder.container_images_template_inputs(
-                namespace='192.0.2.0:5000/tripleoqueens',
+                namespace='192.0.2.0:5000/tripleomaster',
                 ceph_namespace='docker.io/cephh',
                 ceph_image='ceph-daemon',
                 ceph_tag='latest',
@@ -198,7 +196,6 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 name_suffix='suffix',
                 tag='master',
                 neutron_driver='ovn',
-                logging='stdout'
             )
         )
 
@@ -220,24 +217,23 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             tag='liberty'
         )
         container_images = [{
-            'imagename': 'docker.io/tripleoqueens/'
+            'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-compute:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
-            'imagename': 'docker.io/tripleoqueens/'
+            'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-libvirt:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
-            'imagename': 'docker.io/tripleoqueens/image-with-missing-tag',
+            'imagename': 'docker.io/tripleomaster/image-with-missing-tag',
             'push_destination': 'localhost:8787'
         }]
         self.assertEqual(container_images, result)
 
     def _test_container_images_yaml_in_sync_helper(self, neutron_driver=None,
-                                                   remove_images=[],
-                                                   logging='files'):
+                                                   remove_images=[]):
         '''Confirm overcloud_containers.tpl.yaml equals overcloud_containers.yaml
 
         TODO(sbaker) remove when overcloud_containers.yaml is deleted
@@ -257,7 +253,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             return entry
 
         result = tmpl_builder.container_images_from_template(
-            filter=ffunc, neutron_driver=neutron_driver, logging=logging)
+            filter=ffunc, neutron_driver=neutron_driver)
 
         oc_yaml_file = os.path.join(files_dir, 'overcloud_containers.yaml')
         yaml_builder = kb.KollaImageBuilder([oc_yaml_file])
@@ -273,90 +269,61 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
     def test_container_images_yaml_in_sync(self):
         remove_images = [
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-neutron-metadata-agent-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-rsyslog-base:current-tripleo'}]
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
+                          '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
 
     def test_container_images_yaml_in_sync_for_odl(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-neutron-metadata-agent-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-rsyslog-base:current-tripleo'}]
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
+                          '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
 
     def test_container_images_yaml_in_sync_for_ovn(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-rsyslog-base:current-tripleo'}]
+            {'imagename': 'docker.io/tripleomaster/centos-binary'
+                          '-opendaylight:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
 
-    def test_container_images_yaml_in_sync_for_stdout_logging(self):
-        remove_images = [
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
-                          'northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
-                          'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
-                          'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
-                          'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleoqueens/centos-binary'
-                          '-neutron-metadata-agent-ovn:current-tripleo'}]
-        self._test_container_images_yaml_in_sync_helper(
-            remove_images=remove_images, logging='stdout')
-
 
 class TestPrepare(base.TestCase):
 
@@ -511,19 +478,24 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_ovn(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': 't/p-neutron-server-ovn:l'}
+                {'imagename': 't/p-neutron-server-ovn:l'},
+                {'imagename': 't/p-ovn-controller:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/p-neutron-server-ovn:l',
-                'DockerNeutronConfigImage': 't/p-neutron-server-ovn:l'
+                'DockerNeutronConfigImage': 't/p-neutron-server-ovn:l',
+                'DockerOvnControllerConfigImage': 't/p-ovn-controller:l',
+                'DockerOvnControllerImage': 't/p-ovn-controller:l'
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
                 output_env_file=constants.CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
-                service_filter=['OS::TripleO::Services::NeutronServer'],
+                service_filter=[
+                    'OS::TripleO::Services::NeutronServer',
+                    'OS::TripleO::Services::OVNController'
+                ],
                 mapping_args={
-                    'neutron_driver': 'ovn',
                     'namespace': 't',
                     'name_prefix': 'p',
                     'name_suffix': '',
@@ -536,23 +508,229 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_odl(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': 't/p-neutron-server-opendaylight:l'}
+                {'imagename': 't/neutron-server-opendaylight:l'},
+                {'imagename': 't/opendaylight:l'}
             ],
             'environments/containers-default-parameters.yaml': {
-                'DockerNeutronApiImage': 't/p-neutron-server-opendaylight:l',
-                'DockerNeutronConfigImage': 't/p-neutron-server-opendaylight:l'
+                'DockerNeutronApiImage': 't/neutron-server-opendaylight:l',
+                'DockerNeutronConfigImage': 't/neutron-server-opendaylight:l',
+                'DockerOpendaylightApiImage': 't/opendaylight:l',
+                'DockerOpendaylightConfigImage': 't/opendaylight:l',
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
                 output_env_file=constants.CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
-                service_filter=['OS::TripleO::Services::NeutronServer'],
+                service_filter=[
+                    'OS::TripleO::Services::NeutronServer',
+                    'OS::TripleO::Services::OpenDaylightApi'
+                ],
                 mapping_args={
-                    'neutron_driver': 'odl',
                     'namespace': 't',
-                    'name_prefix': 'p',
+                    'name_prefix': '',
                     'name_suffix': '',
                     'tag': 'l',
                 }
             )
         )
+
+    def test_get_enabled_services_empty(self):
+        self.assertEqual(
+            set([]),
+            kb.get_enabled_services({}, [])
+        )
+
+    def test_get_enabled_services_default_count(self):
+        self.assertEqual(
+            set([
+                'OS::TripleO::Services::NeutronApi',
+                'OS::TripleO::Services::NovaApi',
+                'OS::TripleO::Services::NovaCompute'
+            ]),
+            kb.get_enabled_services({
+                'parameter_defaults': {}
+            }, [
+                {
+                    'name': 'Controller',
+                    'CountDefault': 1,
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::NeutronApi',
+                        'OS::TripleO::Services::NovaApi'
+                    ]
+                }, {
+                    'name': 'Compute',
+                    'CountDefault': 1,
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::NovaCompute'
+                    ]
+                }, {
+                    'name': 'BlockStorage',
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::Ntp'
+                    ]
+                }
+            ])
+        )
+
+    def test_get_enabled_services(self):
+        self.assertEqual(
+            set([
+                'OS::TripleO::Services::NeutronApi',
+                'OS::TripleO::Services::NovaApi',
+                'OS::TripleO::Services::NovaCompute',
+                'OS::TripleO::Services::NovaLibvirt'
+            ]),
+            kb.get_enabled_services({
+                'parameter_defaults': {
+                    'ControllerCount': 1,
+                    'ComputeCount': 1,
+                    'BlockStorageCount': 0,
+                    'ComputeServices': [
+                        'OS::TripleO::Services::NovaCompute',
+                        'OS::TripleO::Services::NovaLibvirt'
+                    ]
+                }
+            }, [
+                {
+                    'name': 'Controller',
+                    'CountDefault': 0,
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::NeutronApi',
+                        'OS::TripleO::Services::NovaApi'
+                    ]
+                }, {
+                    'name': 'Compute',
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::NovaCompute'
+                    ]
+                }, {
+                    'name': 'BlockStorage',
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::Ntp'
+                    ]
+                }
+            ])
+        )
+
+    def test_build_service_filter(self):
+        self.assertEqual(
+            set([
+                'OS::TripleO::Services::NovaApi',
+                'OS::TripleO::Services::NovaCompute'
+            ]),
+            kb.build_service_filter({
+                'resource_registry': {
+                    'OS::TripleO::Services::NeutronApi':
+                    '/tht/puppet/services/foo.yaml',
+                    'OS::TripleO::Services::NovaApi':
+                    '/tht/docker/services/foo.yaml',
+                    'OS::TripleO::Services::NovaCompute':
+                    '/tht/docker/services/foo.yaml',
+                }
+            }, [
+                {
+                    'name': 'Controller',
+                    'CountDefault': 1,
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::NeutronApi',
+                        'OS::TripleO::Services::NovaApi'
+                    ]
+                }, {
+                    'name': 'Compute',
+                    'CountDefault': 1,
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::NovaCompute'
+                    ]
+                }, {
+                    'name': 'BlockStorage',
+                    'ServicesDefault': [
+                        'OS::TripleO::Services::Ntp'
+                    ]
+                }
+            ])
+        )
+
+    @mock.patch('tripleo_common.image.kolla_builder.container_images_prepare')
+    @mock.patch('tripleo_common.image.image_uploader.ImageUploadManager',
+                autospec=True)
+    def test_container_images_prepare_multi(self, mock_im, mock_cip):
+        mapping_args = {
+            'namespace': 't',
+            'name_prefix': '',
+            'name_suffix': '',
+            'tag': 'l',
+        }
+        env = {
+            'parameter_defaults': {
+                'ContainerImagePrepare': [{
+                    'set': mapping_args,
+                    'tag_from_label': 'foo',
+                }, {
+                    'set': mapping_args,
+                    'tag_from_label': 'bar',
+                    'excludes': ['nova', 'neutron'],
+                    'push_destination': '192.0.2.1:8787'
+                }]
+            }
+        }
+        roles_data = []
+        mock_cip.side_effect = [
+            {
+                'image_params': {
+                    'FooImage': 't/foo:latest',
+                    'BarImage': 't/bar:latest',
+                    'BazImage': 't/baz:latest',
+                    'BinkImage': 't/bink:latest'
+                },
+                'upload_data': []
+            }, {
+                'image_params': {
+                    'BarImage': 't/bar:1.0',
+                    'BazImage': 't/baz:1.0'
+                },
+                'upload_data': [{
+                    'imagename': 't/bar:1.0',
+                    'push_destination': '192.0.2.1:8787'
+                }, {
+                    'imagename': 't/baz:1.0',
+                    'push_destination': '192.0.2.1:8787'
+                }]
+            },
+        ]
+
+        image_params = kb.container_images_prepare_multi(env, roles_data)
+
+        mock_cip.assert_has_calls([
+            mock.call(
+                excludes=None,
+                mapping_args=mapping_args,
+                output_env_file='image_params',
+                output_images_file='upload_data',
+                pull_source=None,
+                push_destination=None,
+                service_filter=set([]),
+                tag_from_label='foo'
+            ),
+            mock.call(
+                excludes=['nova', 'neutron'],
+                mapping_args=mapping_args,
+                output_env_file='image_params',
+                output_images_file='upload_data',
+                pull_source=None,
+                push_destination='192.0.2.1:8787',
+                service_filter=set([]),
+                tag_from_label='bar'
+            )
+        ])
+
+        mock_im.assert_called_once()
+
+        self.assertEqual(
+            {
+                'BarImage': 't/bar:1.0',
+                'BazImage': 't/baz:1.0',
+                'BinkImage': 't/bink:latest',
+                'FooImage': 't/foo:latest'
+            },
+            image_params
+        )
