@@ -189,23 +189,45 @@ class TestInventory(base.TestCase):
         ansible_ssh_user = 'heat-admin'
         expected = {
             'Compute': {
-                'hosts': ['cp-0'],
+                'hosts': {
+                    'cp-0': {
+                        'ansible_host': 'y.y.y.1',
+                        'ctlplane_ip': 'y.y.y.1',
+                        'deploy_server_id': 'd',
+                        'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'Compute',
-                         'tripleo_role_name': 'Compute'}},
+                         'role_name': 'Compute'}},
             'Controller': {
-                'hosts': ['c-0', 'c-1', 'c-2'],
+                'hosts': {
+                    'c-0': {
+                        'ansible_host': 'x.x.x.1',
+                        'ctlplane_ip': 'x.x.x.1',
+                        'deploy_server_id': 'a',
+                        'enabled_networks': ['ctlplane']},
+                    'c-1': {
+                        'ansible_host': 'x.x.x.2',
+                        'ctlplane_ip': 'x.x.x.2',
+                        'deploy_server_id': 'b',
+                        'enabled_networks': ['ctlplane']},
+                    'c-2': {
+                        'ansible_host': 'x.x.x.3',
+                        'ctlplane_ip': 'x.x.x.3',
+                        'deploy_server_id': 'c',
+                        'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'Controller',
-                         'tripleo_role_name': 'Controller'}},
+                         'role_name': 'Controller'}},
             'CustomRole': {
-                'hosts': ['cs-0'],
+                'hosts': {
+                    'cs-0': {
+                        'ansible_host': 'z.z.z.1',
+                        'ctlplane_ip': 'z.z.z.1',
+                        'deploy_server_id': 'e',
+                        'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'CustomRole',
-                         'tripleo_role_name': 'CustomRole'}},
+                         'role_name': 'CustomRole'}},
 
             'overcloud': {
                 'children': ['Compute', 'Controller', 'CustomRole'],
@@ -213,10 +235,10 @@ class TestInventory(base.TestCase):
                     'ctlplane_vip': 'x.x.x.4',
                     'redis_vip': 'x.x.x.6'}},
             'Undercloud': {
-                'hosts': ['undercloud'],
+                'hosts': {
+                    'undercloud': {
+                        'ansible_host': 'localhost'}},
                 'vars': {'ansible_connection': 'local',
-                         'ansible_host': 'localhost',
-                         'ansible_remote_tmp': '/tmp/ansible-${USER}',
                          'auth_url': 'xyz://keystone.local',
                          'cacert': 'acacert',
                          'os_auth_token': 'atoken',
@@ -262,33 +284,55 @@ class TestInventory(base.TestCase):
 
         expected = {
             'Compute': {
-                'hosts': ['cp-0'],
+                'hosts': {
+                    'cp-0': {
+                        'ansible_host': 'y.y.y.1',
+                        'ctlplane_ip': 'y.y.y.1',
+                        'deploy_server_id': 'd',
+                        'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'Compute',
-                         'tripleo_role_name': 'Compute'}},
+                         'role_name': 'Compute'}},
             'Controller': {
-                'hosts': ['c-0', 'c-1', 'c-2'],
+                'hosts': {
+                    'c-0': {
+                        'ansible_host': 'x.x.x.1',
+                        'ctlplane_ip': 'x.x.x.1',
+                        'deploy_server_id': 'a',
+                        'enabled_networks': ['ctlplane']},
+                    'c-1': {
+                        'ansible_host': 'x.x.x.2',
+                        'ctlplane_ip': 'x.x.x.2',
+                        'deploy_server_id': 'b',
+                        'enabled_networks': ['ctlplane']},
+                    'c-2': {
+                        'ansible_host': 'x.x.x.3',
+                        'ctlplane_ip': 'x.x.x.3',
+                        'deploy_server_id': 'c',
+                        'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'Controller',
-                         'tripleo_role_name': 'Controller'}},
+                         'role_name': 'Controller'}},
             'CustomRole': {
-                'hosts': ['cs-0'],
+                'hosts': {
+                    'cs-0': {
+                        'ansible_host': 'z.z.z.1',
+                        'ctlplane_ip': 'z.z.z.1',
+                        'deploy_server_id': 'e',
+                        'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'CustomRole',
-                         'tripleo_role_name': 'CustomRole'}},
+                         'role_name': 'CustomRole'}},
             'overcloud': {
                 'children': ['Compute', 'Controller', 'CustomRole'],
                 'vars': {
                     'ctlplane_vip': 'x.x.x.4',
                     'redis_vip': 'x.x.x.6'}},
             'Undercloud': {
-                'hosts': ['undercloud'],
+                'hosts': {
+                    'undercloud': {
+                        'ansible_host': 'localhost'}},
                 'vars': {'ansible_connection': 'local',
-                         'ansible_host': 'localhost',
-                         'ansible_remote_tmp': '/tmp/ansible-${USER}',
                          'auth_url': 'xyz://keystone.local',
                          'cacert': 'acacert',
                          'os_auth_token':
@@ -334,8 +378,7 @@ class TestInventory(base.TestCase):
                         'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'Compute',
-                         'tripleo_role_name': 'Compute'}},
+                         'role_name': 'Compute'}},
             'Controller': {
                 'hosts': {
                     'c-0': {
@@ -355,8 +398,7 @@ class TestInventory(base.TestCase):
                         'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'Controller',
-                         'tripleo_role_name': 'Controller'}},
+                         'role_name': 'Controller'}},
             'CustomRole': {
                 'hosts': {
                     'cs-0': {
@@ -366,8 +408,8 @@ class TestInventory(base.TestCase):
                         'enabled_networks': ['ctlplane']}},
                 'vars': {'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
-                         'role_name': 'CustomRole',
-                         'tripleo_role_name': 'CustomRole'}},
+                         'role_name': 'CustomRole'}},
+            '_meta': {'hostvars': {}},
             'overcloud': {'children': {'Compute': {},
                                        'Controller': {},
                                        'CustomRole': {}},
@@ -385,11 +427,9 @@ class TestInventory(base.TestCase):
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
             'sh': {'children': {'CustomRole': {}},
                    'vars': {'ansible_ssh_user': 'heat-admin'}},
-            'Undercloud': {'hosts': {'undercloud': {}},
+            'Undercloud': {'hosts': {'undercloud': {
+                                     'ansible_host': 'localhost'}},
                            'vars': {'ansible_connection': 'local',
-                                    'ansible_host': 'localhost',
-                                    'ansible_remote_tmp':
-                                        '/tmp/ansible-${USER}',
                                     'auth_url': 'xyz://keystone.local',
                                     'cacert': 'acacert',
                                     'os_auth_token': 'atoken',
