@@ -227,44 +227,6 @@ class iBootDriverInfoTest(base.TestCase):
                          self.driver_info.unique_id_from_node(node))
 
 
-class UcsDriverInfoTest(base.TestCase):
-    driver_info = nodes.UcsDriverInfo()
-
-    def test_convert_key(self):
-        keys = {
-            'pm_addr': 'ucs_address',
-            'pm_user': 'ucs_username',
-            'pm_password': 'ucs_password',
-            'pm_service_profile': 'ucs_service_profile'
-        }
-        for key, expected in keys.items():
-            self.assertEqual(expected, self.driver_info.convert_key(key))
-
-        self.assertIsNone(self.driver_info.convert_key('unknown'))
-
-    def test_unique_id_from_fields(self):
-        fields = {
-            'pm_addr': '127.0.0.1',
-            'pm_user': 'user',
-            'pm_password': '123456',
-            "pm_service_profile": 'org-root/org-CPC/ls-CPC-test'
-        }
-        self.assertEqual('127.0.0.1:org-root/org-CPC/ls-CPC-test',
-                         self.driver_info.unique_id_from_fields(fields))
-
-    def test_unique_id_from_node(self):
-        node = mock.Mock(
-            driver_info={
-                'ucs_address': '127.0.0.1',
-                'ucs_username': 'user',
-                'ucs_password': '123456',
-                "ucs_service_profile": 'org-root/org-CPC/ls-CPC-test'
-            }
-        )
-        self.assertEqual('127.0.0.1:org-root/org-CPC/ls-CPC-test',
-                         self.driver_info.unique_id_from_node(node))
-
-
 class FindNodeHandlerTest(base.TestCase):
     def test_found(self):
         test = [('fake', 'fake'),
@@ -511,52 +473,6 @@ class NodesTest(base.TestCase):
         nodes._update_or_register_ironic_node(node, node_map, client=ironic)
         ironic.node.update.assert_called_once_with(1, mock.ANY)
 
-    def test_register_update_caps_dict(self):
-        interfaces = {'boot_interface': 'pxe',
-                      'console_interface': 'ipmitool-socat',
-                      'deploy_interface': 'direct',
-                      'inspect_interface': 'inspector',
-                      'management_interface': 'ipmitool',
-                      'network_interface': 'neutron',
-                      'power_interface': 'ipmitool',
-                      'raid_interface': 'agent',
-                      'storage_interface': 'cinder',
-                      'vendor_interface': 'ipmitool'}
-
-        node = self._get_node()
-        node.update(interfaces)
-        node['root_device'] = {'serial': 'abcdef'}
-        node['capabilities'] = {'profile': 'compute', 'num_nics': 6}
-        ironic = mock.MagicMock()
-        node_map = {'mac': {'aaa': 1}}
-
-        def side_effect(*args, **kwargs):
-            update_patch = [
-                {'path': '/name', 'value': 'node1'},
-                {'path': '/driver_info/ipmi_password', 'value': 'random'},
-                {'path': '/driver_info/ipmi_address', 'value': 'foo.bar'},
-                {'path': '/properties/memory_mb', 'value': '2048'},
-                {'path': '/properties/local_gb', 'value': '30'},
-                {'path': '/properties/cpu_arch', 'value': 'amd64'},
-                {'path': '/properties/cpus', 'value': '1'},
-                {'path': '/properties/capabilities',
-                 'value': 'num_nics:6,profile:compute'},
-                {'path': '/properties/root_device',
-                 'value': {'serial': 'abcdef'}},
-                {'path': '/driver_info/ipmi_username', 'value': 'test'}]
-            for iface, value in interfaces.items():
-                update_patch.append({'path': '/%s' % iface, 'value': value})
-            for key in update_patch:
-                key['op'] = 'add'
-            self.assertThat(update_patch,
-                            matchers.MatchesSetwise(*(map(matchers.Equals,
-                                                          args[1]))))
-            return mock.Mock(uuid='uuid1')
-
-        ironic.node.update.side_effect = side_effect
-        nodes._update_or_register_ironic_node(node, node_map, client=ironic)
-        ironic.node.update.assert_called_once_with(1, mock.ANY)
-
     def test_register_update_with_images(self):
         node = self._get_node()
         node['kernel_id'] = 'image-k'
@@ -649,9 +565,6 @@ class NodesTest(base.TestCase):
     def test_update_node_ironic_pxe_irmc(self):
         self._update_by_type('pxe_irmc')
 
-    def test_update_node_ironic_xclarity(self):
-        self._update_by_type('xclarity')
-
     def test_update_node_ironic_redfish(self):
         ironic = mock.MagicMock()
         node_map = {'mac': {}, 'pm_addr': {}}
@@ -899,25 +812,6 @@ class NodesTest(base.TestCase):
                     'pm_addr': {'foo.bar': 'id'}}
         self.assertEqual('id', nodes._get_node_id(node, handler, node_map))
 
-    def test_register_ironic_node_xclarity(self):
-        node_properties = {"cpus": "1",
-                           "memory_mb": "2048",
-                           "local_gb": "30",
-                           "cpu_arch": "amd64",
-                           "capabilities": "num_nics:6"}
-        node = self._get_node()
-        node['pm_type'] = 'xclarity'
-        node['pm_port'] = '4444'
-        client = mock.MagicMock()
-        nodes.register_ironic_node(node, client=client)
-        client.node.create.assert_called_once_with(
-            driver='xclarity', name='node1', properties=node_properties,
-            resource_class='baremetal',
-            driver_info={'xclarity_password': 'random',
-                         'xclarity_address': 'foo.bar',
-                         'xclarity_username': 'test',
-                         'xclarity_port': '4444'})
-
 
 class TestPopulateNodeMapping(base.TestCase):
     def test_populate_node_mapping_ironic(self):
@@ -1104,10 +998,8 @@ class TestValidateNodes(base.TestCase):
 
     def test_missing_fields(self):
         for field in ('pm_addr', 'pm_user', 'pm_password'):
-            # NOTE(tonyb): We can't use ipmi here as it's fine with some of
-            # these fields being missing.
             nodes_json = [
-                {'pm_type': 'pxe_drac',
+                {'pm_type': 'pxe_ipmitool',
                  'pm_addr': '1.1.1.1',
                  'pm_user': 'root',
                  'pm_password': 'p@$$w0rd'},
@@ -1118,17 +1010,6 @@ class TestValidateNodes(base.TestCase):
                                    'fields are missing: %s' % field,
                                    nodes.validate_nodes, nodes_json)
 
-    def test_ipmi_missing_user_ok(self):
-        nodes_json = [
-            {'pm_type': 'ipmi',
-             'pm_addr': '1.1.1.1',
-             'pm_password': 'p@$$w0rd'},
-        ]
-
-        # validate_nodes() doesn't have an explicit return which means python
-        # gives us None
-        self.assertEqual(None, nodes.validate_nodes(nodes_json))
-
     def test_duplicate_redfish_node(self):
         nodes_json = [
             {'pm_type': 'redfish',
