@@ -101,14 +101,13 @@ class DriverInfo(object):
 class PrefixedDriverInfo(DriverInfo):
     def __init__(self, prefix, deprecated_mapping=None,
                  has_port=False, address_field='address',
-                 default_port=None,
-                 mandatory_fields=None):
+                 default_port=None):
         mapping = {
             'pm_addr': '%s_%s' % (prefix, address_field),
             'pm_user': '%s_username' % prefix,
             'pm_password': '%s_password' % prefix,
         }
-        mandatory_fields = mandatory_fields or list(mapping)
+        mandatory_fields = list(mapping)
 
         if has_port:
             mapping['pm_port'] = '%s_port' % prefix
@@ -265,47 +264,15 @@ class iBootDriverInfo(PrefixedDriverInfo):
         return result
 
 
-class UcsDriverInfo(DriverInfo):
-    def __init__(self):
-        mapping = {
-            'pm_addr': 'ucs_address',
-            'pm_user': 'ucs_username',
-            'pm_password': 'ucs_password',
-            'pm_service_profile': 'ucs_service_profile'
-        }
-        mandatory_fields = list(mapping)
-
-        super(UcsDriverInfo, self).__init__(
-            'ucs', mapping,
-            mandatory_fields=mandatory_fields
-        )
-
-    def unique_id_from_fields(self, fields):
-        try:
-            return '%s:%s' % (fields['pm_addr'], fields['pm_service_profile'])
-
-        except KeyError:
-            return
-
-    def unique_id_from_node(self, node):
-        try:
-            return '%s:%s' % (node.driver_info['ucs_address'],
-                              node.driver_info['ucs_service_profile'])
-        except KeyError:
-            return
-
-
 DRIVER_INFO = {
     # production drivers
     '(ipmi|.*_ipmitool)': PrefixedDriverInfo('ipmi', has_port=True,
-                                             default_port=623,
-                                             mandatory_fields=['pm_addr']),
+                                             default_port=623),
     '(idrac|.*_drac)': PrefixedDriverInfo('drac', has_port=True),
     '(ilo|.*_ilo)': PrefixedDriverInfo('ilo', has_port=True),
-    '(cisco\-ucs\-managed|.*_ucs)': UcsDriverInfo(),
+    '(cisco\-ucs\-managed|.*_ucs)': PrefixedDriverInfo('ucs'),
     '(irmc|.*_irmc)': PrefixedDriverInfo('irmc', has_port=True),
     'redfish': RedfishDriverInfo(),
-    'xclarity': PrefixedDriverInfo('xclarity', has_port=True),
     # test drivers
     'staging\-ovirt': oVirtDriverInfo(),
     '.*_iboot': iBootDriverInfo(),
@@ -454,8 +421,8 @@ _NON_DRIVER_FIELDS = {'cpu': '/properties/cpus',
                       'name': '/name',
                       'resource_class': '/resource_class',
                       'kernel_id': '/driver_info/deploy_kernel',
-                      'ramdisk_id': '/driver_info/deploy_ramdisk'}
-
+                      'ramdisk_id': '/driver_info/deploy_ramdisk',
+                      'capabilities': '/properties/capabilities'}
 
 _NON_DRIVER_FIELDS.update({field: '/%s' % field
                            for field in _KNOWN_INTERFACE_FIELDS})
@@ -474,10 +441,6 @@ def _update_or_register_ironic_node(node, node_map, client):
             if field in node:
                 patched[path] = node.pop(field)
 
-        if 'capabilities' in node:
-            patched['/properties/capabilities'] = dict_to_capabilities(
-                node.pop('capabilities'))
-
         driver_info = handler.convert(node)
         for key, value in driver_info.items():
             patched['/driver_info/%s' % key] = value
@@ -543,10 +506,6 @@ def register_all_nodes(nodes_list, client, remove=False, glance_client=None,
     return seen
 
 
-# These fields are treated specially during enrolling/updating
-_SPECIAL_NON_DRIVER_FIELDS = {'mac', 'pm_type', 'capabilities'}
-
-
 def validate_nodes(nodes_list):
     """Validate all nodes list.
 
@@ -610,7 +569,7 @@ def validate_nodes(nodes_list):
         for field in node:
             converted = handler.convert_key(field)
             if (converted is None and field not in _NON_DRIVER_FIELDS and
-                    field not in _SPECIAL_NON_DRIVER_FIELDS):
+                    field not in ('mac', 'pm_type')):
                 failures.append((index, 'Unknown field %s' % field))
 
     if failures:
@@ -620,14 +579,8 @@ def validate_nodes(nodes_list):
 
 def dict_to_capabilities(caps_dict):
     """Convert a dictionary into a string with the capabilities syntax."""
-    if isinstance(caps_dict, six.string_types):
-        return caps_dict
-
-    # NOTE(dtantsur): sort capabilities so that their order does not change
-    # between updates.
-    items = sorted(caps_dict.items(), key=lambda tpl: tpl[0])
     return ','.join(["%s:%s" % (key, value)
-                     for key, value in items
+                     for key, value in caps_dict.items()
                      if value is not None])
 
 
@@ -681,10 +634,7 @@ def generate_hostmap(baremetal_client, compute_client):
         for port in baremetal_client.port.list(node=bm_node.uuid):
             hostmap[port.address] = {"compute_name": node.name,
                                      "baremetal_name": bm_node.name}
-    if hostmap == {}:
-        return None
-    else:
-        return hostmap
+    return hostmap
 
 
 def run_nova_cell_v2_discovery():
@@ -707,15 +657,3 @@ def get_node_profile(node):
         return capabilities_dict['profile']
 
     return None
-
-
-def get_node_hint(node):
-    """Return the 'capabilities:node' hint associated with the node """
-
-    capabilities = node.get('properties').get('capabilities')
-    capabilities_dict = capabilities_to_dict(capabilities)
-
-    if 'node' in capabilities_dict:
-        return capabilities_dict['node']
-
-    return None
